@@ -322,7 +322,7 @@ class square_grid:
         
         if data.crs == None:
             data.crs = {'init': 'epsg:4326'}
-            length = (self.spacing/1.0e6)
+            length = (self.spacing/1.0e5)
         else:
             length = self.spacing
         
@@ -353,6 +353,40 @@ class square_grid:
                 res = gpd.GeoDataFrame(geometry=gpd.GeoSeries(res_geoms).apply(lambda x: Polygon(x)),crs=data.crs).intersection(unary_union(data.geometry).convex_hull)
             res = res[res.geometry.type == 'Polygon']
             res.index = [i for i in range(len(res))]
-            self.geosolution =  gpd.GeoDataFrame(geometry=res)
+            dfds =  gpd.GeoDataFrame(geometry=res)
+            datax = gpd.GeoDataFrame(crs = {'init': 'epsg:4326'})
+            for index, row in tqdm(dfds.iterrows(), total = dfds.shape[0]):
+                if row['geometry'] != None and row['geometry'].geom_type == 'Polygon':
+                    df = gpd.GeoDataFrame(geometry=gpd.GeoSeries(row['geometry']))
+                    datax = datax.append(df, sort = False)
+                else:
+                    pass
+            if datax.crs ==None:
+                datax.crs ={'init': 'epsg:4326'}
+            final_hexa =gpd.overlay(data.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
+                                    gpd.overlay(data.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
+                                                datax, how='intersection'),
+                                    how = 'union')[['geometry']].copy()
+            area_thresholda = (length*length)*0.33
+            disolve_square = dissolve_polygon(final_hexa, area_thresholda).geosolution
+            check_topology(disolve_square)
+            self.geosolution = disolve_square
         else:
-            self.geosolution = gpd.GeoDataFrame(index=[i for i in range(len(res_geoms))],geometry=gpd.GeoSeries(res_geoms).apply(lambda x: Polygon(x)),crs=data.crs)
\ No newline at end of file
+            dfds = gpd.GeoDataFrame(index=[i for i in range(len(res_geoms))],geometry=gpd.GeoSeries(res_geoms).apply(lambda x: Polygon(x)),crs=data.crs)
+            datax = gpd.GeoDataFrame(crs = {'init': 'epsg:4326'})
+            for index, row in tqdm(dfds.iterrows(), total = dfds.shape[0]):
+                if row['geometry'] != None and row['geometry'].geom_type == 'Polygon':
+                    df = gpd.GeoDataFrame(geometry=gpd.GeoSeries(row['geometry']))
+                    datax = datax.append(df, sort = False)
+                else:
+                    pass
+            if datax.crs ==None:
+                datax.crs ={'init': 'epsg:4326'}
+            final_hexa =gpd.overlay(data.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
+                                    gpd.overlay(data.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
+                                                datax, how='intersection'),
+                                    how = 'union')[['geometry']].copy()
+            area_thresholda = (length*length)*0.33
+            disolve_square = dissolve_polygon(final_hexa, area_thresholda).geosolution
+            check_topology(disolve_square)
+            self.geosolution = disolve_square
\ No newline at end of file
